@@ -4,7 +4,9 @@ from __future__ import absolute_import
 from __future__ import division, print_function, unicode_literals
 
 import re
+import string
 import zipfile
+
 import nltk
 
 from .._compat import to_string, to_unicode, unicode
@@ -12,10 +14,30 @@ from ..utils import normalize_language
 
 
 class DefaultWordTokenizer(object):
+    """NLTK tokenizer"""
     def tokenize(self, text):
         return nltk.word_tokenize(text)
 
 
+class HebrewWordTokenizer:
+    """https://github.com/iddoberger/awesome-hebrew-nlp"""
+    _TRANSLATOR = str.maketrans("", "", string.punctuation)
+
+    @classmethod
+    def tokenize(cls, text):
+        try:
+            from hebrew_tokenizer import tokenize
+            from hebrew_tokenizer.groups import Groups
+        except ImportError:
+            raise ValueError("Hebrew tokenizer requires hebrew_tokenizer. Please, install it by command 'pip install hebrew_tokenizer'.")
+
+        text = text.translate(cls._TRANSLATOR)
+        return [
+            word for token, word, _, _ in tokenize(text)
+            if token in (Groups.HEBREW, Groups.HEBREW_1, Groups.HEBREW_2)
+        ]
+
+
 class JapaneseWordTokenizer:
     def tokenize(self, text):
         try:
@@ -35,10 +57,30 @@ class ChineseWordTokenizer:
         return jieba.cut(text)
 
 
+class KoreanSentencesTokenizer:
+    def tokenize(self, text):
+        try:
+            from konlpy.tag import Kkma
+        except ImportError as e:
+            raise ValueError("Korean tokenizer requires konlpy. Please, install it by command 'pip install konlpy'.")
+        kkma = Kkma()
+        return kkma.sentences(text)
+
+
+class KoreanWordTokenizer:
+    def tokenize(self, text):
+        try:
+            from konlpy.tag import Kkma
+        except ImportError as e:
+            raise ValueError("Korean tokenizer requires konlpy. Please, install it by command 'pip install konlpy'.")
+        kkma = Kkma()
+        return kkma.nouns(text)
+
+
 class Tokenizer(object):
     """Language dependent tokenizer of text document."""
 
-    _WORD_PATTERN = re.compile(r"^[^\W\d_]+$", re.UNICODE)
+    _WORD_PATTERN = re.compile(r"^[^\W\d_](?:[^\W\d_]|['-])*$", re.UNICODE)
     # feel free to contribute if you have better tokenizer for any of these languages :)
     LANGUAGE_ALIASES = {
         "slovak": "czech",
@@ -52,13 +94,17 @@ class Tokenizer(object):
     }
 
     SPECIAL_SENTENCE_TOKENIZERS = {
+        'hebrew': nltk.RegexpTokenizer(r'\.\s+', gaps=True),
         'japanese': nltk.RegexpTokenizer('[^　！？。]*[！？。]'),
-        'chinese': nltk.RegexpTokenizer('[^　！？。]*[！？。]')
+        'chinese': nltk.RegexpTokenizer('[^　！？。]*[！？。]'),
+        'korean': KoreanSentencesTokenizer(),
     }
 
     SPECIAL_WORD_TOKENIZERS = {
+        'hebrew': HebrewWordTokenizer(),
         'japanese': JapaneseWordTokenizer(),
         'chinese': ChineseWordTokenizer(),
+        'korean': KoreanWordTokenizer(),
     }
 
     def __init__(self, language):
@@ -79,10 +125,11 @@ class Tokenizer(object):
         try:
             path = to_string("tokenizers/punkt/%s.pickle") % to_string(language)
             return nltk.data.load(path)
-        except (LookupError, zipfile.BadZipfile):
+        except (LookupError, zipfile.BadZipfile) as e:
             raise LookupError(
-                "NLTK tokenizers are missing. Download them by following command: "
-                '''python -c "import nltk; nltk.download('punkt')"'''
+                "NLTK tokenizers are missing or the language is not supported.\n"
+                """Download them by following command: python -c "import nltk; nltk.download('punkt')"\n"""
+                "Original error was:\n" + str(e)
             )
 
     def _get_word_tokenizer(self, language):
@@ -102,5 +149,6 @@ class Tokenizer(object):
         words = self._word_tokenizer.tokenize(to_unicode(sentence))
         return tuple(filter(self._is_word, words))
 
-    def _is_word(self, word):
-        return bool(Tokenizer._WORD_PATTERN.search(word))
+    @staticmethod
+    def _is_word(word):
+        return bool(Tokenizer._WORD_PATTERN.match(word))
