@@ -35,7 +35,7 @@ class DocumentParser(object):
         self._tokenizer = tokenizer
 
     def tokenize_sentences(self, paragraph):
-        return self._tokenizer.to_sentences(paragraph)
+        return [s for s in self._tokenizer.to_sentences(paragraph) if s.strip()]
 
     def tokenize_words(self, sentence):
         return self._tokenizer.to_words(sentence)
